==> intel-media-driver_23.1.1+dfsg1.orig.tar.xz: media-driver-intel-media-23.1.1/media_softlet/agnostic/Xe_M_plus/Xe_LPM_plus_base/codec/hal/enc/hevc/pipeline/encode_hevc_vdenc_pipeline_adapter_xe_lpm_plus_base.h <==
/*
* Copyright (c) 2020, Intel Corporation
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*/
//!
//! \file     encode_hevc_vdenc_pipeline_adapter_xe_lpm_plus_base.h
//! \brief    Defines the interface to adapt to hevc vdenc encode pipeline Xe_LPM_plus+
//!

#ifndef __ENCODE_HEVC_VDENC_PIPELINE_ADAPTER_XE_LPM_PLUS_BASE_H__
#define __ENCODE_HEVC_VDENC_PIPELINE_ADAPTER_XE_LPM_PLUS_BASE_H__

#include "encode_pipeline_adapter.h"
#include "encode_hevc_vdenc_pipeline_xe_lpm_plus_base.h"

class EncodeHevcVdencPipelineAdapterXe_Lpm_Plus_Base : public EncoderPipelineAdapter
{
public:
    EncodeHevcVdencPipelineAdapterXe_Lpm_Plus_Base(
        CodechalHwInterfaceNext *   hwInterface,
        CodechalDebugInterface *debugInterface);

    virtual ~EncodeHevcVdencPipelineAdapterXe_Lpm_Plus_Base() {}

    virtual MOS_STATUS Allocate(CodechalSetting *codecHalSettings);

    virtual MOS_STATUS Execute(void *params);

    virtual MOS_STATUS GetStatusReport(void *status, uint16_t numStatus);

    virtual void Destroy();

protected:
    std::shared_ptr<encode::HevcVdencPipelineXe_Lpm_Plus_Base> m_encoder = nullptr;

MEDIA_CLASS_DEFINE_END(EncodeHevcVdencPipelineAdapterXe_Lpm_Plus_Base)
};
#endif // !__ENCODE_HEVC_VDENC_PIPELINE_ADAPTER_XE_LPM_PLUS_BASE_H__

==> intel-media-driver_25.4.5+dfsg1.orig.tar.xz: media-driver-intel-media-25.4.5/media_softlet/agnostic/Xe_M_plus/Xe_LPM_plus_base/codec/hal/enc/hevc/pipeline/encode_hevc_vdenc_pipeline_adapter_xe_lpm_plus_base.h <==
/*
* Copyright (c) 2020, Intel Corporation
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*/
//!
//! \file     encode_hevc_vdenc_pipeline_adapter_xe_lpm_plus_base.h
//! \brief    Defines the interface to adapt to hevc vdenc encode pipeline Xe_LPM_plus+
//!

#ifndef __ENCODE_HEVC_VDENC_PIPELINE_ADAPTER_XE_LPM_PLUS_BASE_H__
#define __ENCODE_HEVC_VDENC_PIPELINE_ADAPTER_XE_LPM_PLUS_BASE_H__

#include "encode_pipeline_adapter.h"
#include "encode_hevc_vdenc_pipeline_xe_lpm_plus_base.h"

class EncodeHevcVdencPipelineAdapterXe_Lpm_Plus_Base : public EncoderPipelineAdapter
{
public:
    EncodeHevcVdencPipelineAdapterXe_Lpm_Plus_Base(
        CodechalHwInterfaceNext *   hwInterface,
        CodechalDebugInterface *debugInterface);

    virtual ~EncodeHevcVdencPipelineAdapterXe_Lpm_Plus_Base() {}

    virtual MOS_STATUS Allocate(CodechalSetting *codecHalSettings) override;

    virtual MOS_STATUS ResolveMetaData(PMOS_RESOURCE pInput, PMOS_RESOURCE pOutput) override;

    virtual MOS_STATUS Execute(void *params) override;

    virtual MOS_STATUS GetStatusReport(void *status, uint16_t numStatus) override;

    virtual void Destroy() override;

protected:
    std::shared_ptr<encode::HevcVdencPipelineXe_Lpm_Plus_Base> m_encoder = nullptr;

MEDIA_CLASS_DEFINE_END(EncodeHevcVdencPipelineAdapterXe_Lpm_Plus_Base)
};
#endif // !__ENCODE_HEVC_VDENC_PIPELINE_ADAPTER_XE_LPM_PLUS_BASE_H__
